@@ -18,9 +18,11 @@ extern "C" {
 
 LLDB_API SBAddressRef CreateSBAddress(void);
 
-LLDB_API SBAddressRef CreateSBAddress2(SBSectionRef section, lldb_addr_t offset);
+LLDB_API SBAddressRef CreateSBAddress2(SBSectionRef section,
+                                       lldb_addr_t offset);
 
-LLDB_API SBAddressRef CreateSBAddress3(lldb_addr_t load_addr, SBTargetRef target);
+LLDB_API SBAddressRef CreateSBAddress3(lldb_addr_t load_addr,
+                                       SBTargetRef target);
 
 LLDB_API SBAddressRef CloneSBAddress(SBAddressRef instance);
 
@@ -32,17 +34,23 @@ LLDB_API void SBAddressClear(SBAddressRef instance);
 
 LLDB_API lldb_addr_t SBAddressGetFileAddress(SBAddressRef instance);
 
-LLDB_API lldb_addr_t SBAddressGetLoadAddress(SBAddressRef instance, SBTargetRef target);
+LLDB_API lldb_addr_t SBAddressGetLoadAddress(SBAddressRef instance,
+                                             SBTargetRef target);
 
-LLDB_API void SBAddressSetAddress(SBAddressRef instance, SBSectionRef section, lldb_addr_t offset);
+LLDB_API void SBAddressSetAddress(SBAddressRef instance, SBSectionRef section,
+                                  lldb_addr_t offset);
 
-LLDB_API void SBAddressSetLoadAddress(SBAddressRef instance, lldb_addr_t load_addr, SBTargetRef target);
+LLDB_API void SBAddressSetLoadAddress(SBAddressRef instance,
+                                      lldb_addr_t load_addr,
+                                      SBTargetRef target);
 
 LLDB_API bool SBAddressOffsetAddress(SBAddressRef instance, lldb_addr_t offset);
 
-LLDB_API bool SBAddressGetDescription(SBAddressRef instance, SBStreamRef description);
+LLDB_API bool SBAddressGetDescription(SBAddressRef instance,
+                                      SBStreamRef description);
 
-LLDB_API SBSymbolContextRef SBAddressGetSymbolContext(SBAddressRef instance, uint32_t resolve_scope);
+LLDB_API SBSymbolContextRef SBAddressGetSymbolContext(SBAddressRef instance,
+                                                      uint32_t resolve_scope);
 
 LLDB_API SBSectionRef SBAddressGetSection(SBAddressRef instance);
 
