@@ -18,17 +18,25 @@ extern "C" {
 
 LLDB_API SBMemoryRegionInfoListRef CreateSBMemoryRegionInfoList(void);
 
-LLDB_API SBMemoryRegionInfoListRef CloneSBMemoryRegionInfoList(SBMemoryRegionInfoListRef instance);
+LLDB_API SBMemoryRegionInfoListRef
+CloneSBMemoryRegionInfoList(SBMemoryRegionInfoListRef instance);
 
 LLDB_API void DisposeSBMemoryRegionInfoList(SBMemoryRegionInfoListRef instance);
 
-LLDB_API uint32_t SBMemoryRegionInfoListGetSize(SBMemoryRegionInfoListRef instance);
+LLDB_API uint32_t
+SBMemoryRegionInfoListGetSize(SBMemoryRegionInfoListRef instance);
 
-LLDB_API bool SBMemoryRegionInfoListGetMemoryRegionAtIndex(SBMemoryRegionInfoListRef instance, uint32_t idx, SBMemoryRegionInfoRef region);
+LLDB_API bool
+SBMemoryRegionInfoListGetMemoryRegionAtIndex(SBMemoryRegionInfoListRef instance,
+                                             uint32_t idx,
+                                             SBMemoryRegionInfoRef region);
 
-LLDB_API void SBMemoryRegionInfoListAppend(SBMemoryRegionInfoListRef instance, SBMemoryRegionInfoRef region);
+LLDB_API void SBMemoryRegionInfoListAppend(SBMemoryRegionInfoListRef instance,
+                                           SBMemoryRegionInfoRef region);
 
-LLDB_API void SBMemoryRegionInfoListAppendList(SBMemoryRegionInfoListRef instance, SBMemoryRegionInfoListRef region_list);
+LLDB_API void
+SBMemoryRegionInfoListAppendList(SBMemoryRegionInfoListRef instance,
+                                 SBMemoryRegionInfoListRef region_list);
 
 LLDB_API void SBMemoryRegionInfoListClear(SBMemoryRegionInfoListRef instance);
 
