@@ -28,21 +28,22 @@ LLDB_API void SBQueueClear(SBQueueRef instance);
 
 LLDB_API SBProcessRef SBQueueGetProcess(SBQueueRef instance);
 
-LLDB_API unsigned long long SBQueueGetQueueID(SBQueueRef instance);
+LLDB_API lldb_queue_id_t SBQueueGetQueueID(SBQueueRef instance);
 
 LLDB_API const char *SBQueueGetName(SBQueueRef instance);
 
-LLDB_API unsigned int SBQueueGetIndexID(SBQueueRef instance);
+LLDB_API uint32_t SBQueueGetIndexID(SBQueueRef instance);
 
-LLDB_API unsigned int SBQueueGetNumThreads(SBQueueRef instance);
+LLDB_API uint32_t SBQueueGetNumThreads(SBQueueRef instance);
 
 LLDB_API SBThreadRef SBQueueGetThreadAtIndex(SBQueueRef instance, uint32_t);
 
-LLDB_API unsigned int SBQueueGetNumPendingItems(SBQueueRef instance);
+LLDB_API uint32_t SBQueueGetNumPendingItems(SBQueueRef instance);
 
-LLDB_API SBQueueItemRef SBQueueGetPendingItemAtIndex(SBQueueRef instance, uint32_t);
+LLDB_API SBQueueItemRef SBQueueGetPendingItemAtIndex(SBQueueRef instance,
+                                                     uint32_t);
 
-LLDB_API unsigned int SBQueueGetNumRunningItems(SBQueueRef instance);
+LLDB_API uint32_t SBQueueGetNumRunningItems(SBQueueRef instance);
 
 LLDB_API ENUM(QueueKind) SBQueueGetKind(SBQueueRef instance);
 
