@@ -24,15 +24,20 @@ LLDB_API bool SBStreamIsValid(SBStreamRef instance);
 
 LLDB_API const char *SBStreamGetData(SBStreamRef instance);
 
-LLDB_API unsigned int SBStreamGetSize(SBStreamRef instance);
+LLDB_API size_t SBStreamGetSize(SBStreamRef instance);
 
 LLDB_API void SBStreamPrintf(SBStreamRef instance, const char *format, ...);
 
-LLDB_API void SBStreamRedirectToFile(SBStreamRef instance, const char *path, bool append);
+LLDB_API void SBStreamPrint(SBStreamRef instance, const char *str);
 
-LLDB_API void SBStreamRedirectToFileHandle(SBStreamRef instance, FILE *fh, bool transfer_fh_ownership);
+LLDB_API void SBStreamRedirectToFile(SBStreamRef instance, const char *path,
+                                     bool append);
 
-LLDB_API void SBStreamRedirectToFileDescriptor(SBStreamRef instance, int fd, bool transfer_fh_ownership);
+LLDB_API void SBStreamRedirectToFileHandle(SBStreamRef instance, FILE *fh,
+                                           bool transfer_fh_ownership);
+
+LLDB_API void SBStreamRedirectToFileDescriptor(SBStreamRef instance, int fd,
+                                               bool transfer_fh_ownership);
 
 LLDB_API void SBStreamClear(SBStreamRef instance);
 
